@@ -11,7 +11,7 @@ LWP::UserAgent::Paranoid - A modern LWPx::ParanoidAgent for safer requests
 package LWP::UserAgent::Paranoid;
 use base 'LWP::UserAgent';
 
-our $VERSION = "0.96";
+our $VERSION = "0.97";
 
 use Scalar::Util          qw/ refaddr /;
 use Time::HiRes           qw/ alarm /;
@@ -30,7 +30,7 @@ use Carp                  qw//;
     my $response = $ua->get("http://example.com");
 
     # allow requests to localhost and 127.0.0.1
-    $ua->resolver->whitelisted_hosts(['localhost', '127.0.0.1']);
+    $ua->whitelisted_hosts('localhost', '127.0.0.1');
 
 =head1 DESCRIPTION
 
@@ -52,7 +52,12 @@ stalling redirects.  The default is 5 seconds.
 All new agents are automatically made paranoid of private hostnames and IP
 address ranges using L<LWPx::ParanoidHandler>.  You may access the
 L<Net::DNS::Paranoid> resolver via the L</resolver> method in order to
-customize the blocked or whitelisted hosts.
+customize its behaviour.
+
+For simple whitelisting and blacklisting, you may call L</whitelisted_hosts> or
+L</blocked_hosts>.  These methods are proxied to the corresponding methods
+of L<Net::DNS::Paranoid>.  The only difference is that you may pass a list to
+this class' methods.
 
 =head1 EVEN MORE PARANOIA
 
@@ -96,8 +101,14 @@ need to set your own but if you do it should be an L<Net::DNS::Paranoid>
 object.  This attribute is read-only, so if you want to replace the resolver
 you need to call L</new> again to create a new L<LWP::UserAgent::Paranoid>.
 
-Use the blocking and whitelisting methods on the resolver to customize the
-behaviour.
+Use the blocking and whitelisting methods on the resolver, or this class'
+L</whitelisted_hosts> and L</blocked_hosts>, to customize the behaviour.
+
+=head2 whitelisted_hosts / blocked_hosts
+
+Accepts a single arrayref and proxies to the method of the same name on the
+L</resolver>.  For convenience, you may pass a list which will be passed as an
+arrayref to the resolver's method.
 
 =cut
 
@@ -110,11 +121,16 @@ sub new {
     my $resolver = delete $opts{resolver};
        $resolver = Net::DNS::Paranoid->new unless $resolver;
 
+    for my $acl (qw(blocked_hosts whitelisted_hosts)) {
+        next unless $opts{$acl};
+        $resolver->$acl( delete $opts{$acl} );
+    }
+
     my $self = $class->SUPER::new(%opts);
     $self->request_timeout($timeout);
     $self->_elem("resolver", $resolver);
 
-    LWPx::ParanoidHandler::make_paranoid($self, $self->resolver);
+    LWPx::ParanoidHandler::make_paranoid($self, $self->_resolver);
 
     return $self;
 }
@@ -124,8 +140,14 @@ sub resolver        {
     my $self = shift;
     Carp::croak("resolver is read-only; to use a new resolver, create a new user agent")
         if @_;
-    return $self->_elem("resolver");
+    return $self->_resolver;
 }
+sub _resolver {
+    shift->_elem("resolver");
+}
+
+sub blocked_hosts     { shift->_resolver->blocked_hosts(ref $_[0] ? $_[0] : \@_) }
+sub whitelisted_hosts { shift->_resolver->whitelisted_hosts(ref $_[0] ? $_[0] : \@_) }
 
 sub __timed_out { Carp::croak("Client timed out request") }
 sub __with_timeout {
@@ -173,7 +195,8 @@ Thomas Sibley <tsibley@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
  
-This software is Copyright (c) 2013 by Best Practical Solutions
+This software is primarily Copyright (c) 2013 by Best Practical Solutions,
+with parts of it Copyright (c) 2014-2015 by Thomas Sibley.
  
 This is free software, licensed under:
  
